@@ -1,7 +1,7 @@
 __author__ = "Rashtrapathy"
-__copyright__ = "Copyright (c) 2018-2020 by Iotium, Inc."
+__copyright__ = "Copyright (c) 2018-2021 by Iotium, Inc."
 __license__ = "All rights reserved."
-__version__ = "20.8.9"
+__version__ = "21.09.15"
 __credits__ = ["Rashtrapathy", "Thyagarajan", "Jawahar", "Venkatesan", "Raja"]
 __maintainer__ = "Rashtrapathy"
 __email__ = "rashtrapathy.c@iotium.io"
@@ -23,4 +23,6 @@ from .user import *
 #from .user import mysubscriptions
 from .helper import get_resource_id_by_name, get_all_networks_from_node, get_resource_name_by_id, get_resource_by_label
 from .sshkey import *
-from .cluster import *
\ No newline at end of file
+from .cluster import *
+from .download import *
+from .nodecli import *
