@@ -196,6 +196,7 @@ class resourcePaylod(object):
             labelObj = resourcePaylod.Metadata.Label()
             dataSavingModeObj = resourcePaylod.iNode.dataSavingMode()
             sshkeyObj = resourcePaylod.iNode.sshKey()
+            containerTimeZoneObj = resourcePaylod.iNode.containerTimeZone
 
             if 'inode_name' in payload and payload['inode_name']:
                 setattr(nodeName_Obj, 'name', payload['inode_name'])
@@ -239,6 +240,10 @@ class resourcePaylod(object):
                 setattr(sshkeyObj, 'ssh_keys', payload['ssh_keys'])
                 self.ssh_keys = getattr(sshkeyObj, 'ssh_keys')
 
+            if 'container_timezone' in payload and payload['container_timezone']:
+                setattr(containerTimeZoneObj, 'container_timezone', payload['container_timezone'])
+                self.container_timezone = getattr(containerTimeZoneObj, 'container_timezone')
+
         class nodeName(object):
             def __init__(self):
                 self._nodeName = str()
@@ -323,6 +328,18 @@ class resourcePaylod(object):
             def ssh_keys(self, key):
                 self._sshkey.append(key)
 
+        class containerTimeZone(object):
+            def __init__(self):
+                self._value = str()
+
+            @property
+            def container_timezone(self):
+                return self._value
+
+            @container_timezone.setter
+            def container_timezone(self, value):
+                self._value = value
+
 
     class Network(object):
         def __init__(self, payload):
@@ -1557,6 +1574,11 @@ class resourcePaylod(object):
                 setattr(InstanceIdObj, "instance_id", payload["instance_id"])
                 self.config = getattr(InstanceIdObj, 'instance_id')
 
+            containerTimeZoneObj = resourcePaylod.Cluster.ContainerTimeZone()
+            if 'container_timezone' in payload and payload['container_timezone'] is not None:
+                setattr(containerTimeZoneObj, 'container_timezone', payload['container_timezone'])
+                self.container_timezone = getattr(containerTimeZoneObj, 'container_timezone')
+
         class ClusterName(object):
             def __init__(self):
                 self._value = str()
@@ -1605,3 +1627,98 @@ class resourcePaylod(object):
             @instance_id.setter
             def instance_id(self, value):
                 self._value['instance_id'] = value
+
+        class ContainerTimeZone(object):
+            def __init__(self):
+                self._value = str()
+
+            @property
+            def container_timezone(self):
+                return self._value
+
+            @container_timezone.setter
+            def container_timezone(self, value):
+                self._value = value
+
+    class DownloadEvent(object):
+        def __init__(self, payload):
+            if payload == {}:
+                return
+
+            orgId_Obj = resourcePaylod.Organisation.orgId()
+            if 'org_id' in payload and payload['org_id'] is not None:
+                setattr(orgId_Obj, 'org_id', payload['org_id'])
+                self.org_id = getattr(orgId_Obj, 'org_id')
+
+            if 'node_id' in payload and payload['node_id'] is not None:
+                self.node_id = payload['node_id']
+
+            if 'cluster_id' in payload and payload['cluster_id'] is not None:
+                self.cluster_id = payload['cluster_id']
+
+            if 'resource_group' in payload and payload['resource_group'] is not None:
+                self.resource_group = payload['resource_group']
+
+            if 'own' in payload and payload['own'] is not None:
+                self.own = payload['own']
+
+            if 'start_date' in payload and payload['start_date'] is not None:
+                self.start_date = payload['start_date']
+
+            if 'end_date' in payload and payload['end_date'] is not None:
+                self.end_date = payload['end_date']
+
+    class DownloadActivity(object):
+        def __init__(self, payload):
+            if payload == {}:
+                return
+
+            orgId_Obj = resourcePaylod.Organisation.orgId()
+            if 'org_id' in payload and payload['org_id'] is not None:
+                setattr(orgId_Obj, 'org_id', payload['org_id'])
+                self.org_id = getattr(orgId_Obj, 'org_id')
+
+            if 'start_date' in payload and payload['start_date'] is not None:
+                self.start_date = payload['start_date']
+
+            if 'end_date' in payload and payload['end_date'] is not None:
+                self.end_date = payload['end_date']
+
+            if 'own' in payload and payload['own'] is not None:
+                self.own = payload['own']
+
+    class iNodeCli(object):
+        def __init__(self, action, payload):
+            if ( action == "set" or action == "unset" ) and \
+                    (payload['command'] == "timeserver" or
+                             payload['command'] == 'nameserver'):
+                self.action = action
+                self.ip_address = payload['params']['ip_address']
+            if action == "set" and payload['command'] == "proxy":
+                self.action = action
+                self.protocol = "HTTPS"
+                if 'username' in payload['params']:
+                    self.url = "{}@{}".format(payload['params']['username'], payload['params']['url'])
+                    self.password = payload['params']['password']
+                else:
+                    self.url = payload['params']['url']
+            if action == "unset" and payload['command'] == "proxy":
+                self.action = action
+                self.protocol = "HTTPS"
+            if action == "set" and payload['command'] == "wan_ip":
+                self.action = action
+                self.ip_address = payload['params']['ip_address']
+                self.netmask = payload['params']['netmask']
+                self.gateway = payload['params']['gateway']
+            if action == "set" and payload['command'] == "wan_vlan":
+                self.action = action
+                self.vlan_id = payload['params']['vlan_id']
+            if action == "set" and payload['command'] == "mgmt_ip":
+                self.action = action
+                self.ip_address = payload['params']['ip_address']
+                self.netmask = payload['params']['netmask']
+            if action == "unset" and \
+                    (payload['command'] == "wan_ip" or
+                             payload['command'] == "mgmt_ip" or
+                             payload['command'] == "wan_vlan"):
+                self.action = action
