@@ -486,7 +486,7 @@ def formattedOutput(resp, method):
                 for ip in range(len(result['status']['service_ip'])):
                     op['ServiceIp'] = result['status']['service_ip'][ip]['ip_address']
                     op['ServiceMacAddress'] = result['status']['service_ip'][ip]['mac_address']
-                    op['NetworkName']=helper.get_resource_name_by_id(network, result['status']['service_ip'][ip]['network_id'])
+                    #op['NetworkName']=helper.get_resource_name_by_id(network, result['status']['service_ip'][ip]['network_id'])
             if 'running' in result['status']:
                 op['TotalContainers'] = result['status']['running']
             if 'message' in result['status']:
@@ -502,7 +502,9 @@ def formattedOutput(resp, method):
                 if 'dns' in result['spec']:
                     op['DnsServerIpAddress'] = ','.join(result['spec']['dns'])
                 else:
-                    if node_name:
+                    if 'dns' in result['status']:
+                        op['DnsServerIpAddress'] = ','.join(result['status']['dns']['nameserver'])
+                    if False:
                         if result['node']['name'] in dict_node_op:
                             node_get_op = dict_node_op[result['node']['name']]
                             if 'node' in node_get_op['status']:
